from setuptools import setup

setup(name='gafs',
      version='0.0.1',
      description='Genetic algorigthm feature selection.',
      packages=['gafs'],
      author_email='sheminy32@gmail.com',
      zip_safe=False)